==> client-java-api-8.0.2-sources.jar: io/kubernetes/client/openapi/models/ExtensionsV1beta1IngressSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.util.Collection;

public interface ExtensionsV1beta1IngressSpecFluent<A extends ExtensionsV1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1IngressBackend getBackend();
    public ExtensionsV1beta1IngressBackend buildBackend();
    public A withBackend(ExtensionsV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(ExtensionsV1beta1IngressBackend item);
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(ExtensionsV1beta1IngressBackend item);
    public A addToRules(int index,ExtensionsV1beta1IngressRule item);
    public A setToRules(int index,ExtensionsV1beta1IngressRule item);
    public A addToRules(ExtensionsV1beta1IngressRule... items);
    public A addAllToRules(Collection<ExtensionsV1beta1IngressRule> items);
    public A removeFromRules(ExtensionsV1beta1IngressRule... items);
    public A removeAllFromRules(Collection<ExtensionsV1beta1IngressRule> items);
    public A removeMatchingFromRules(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IngressRule> getRules();
    public List<ExtensionsV1beta1IngressRule> buildRules();
    public ExtensionsV1beta1IngressRule buildRule(int index);
    public ExtensionsV1beta1IngressRule buildFirstRule();
    public ExtensionsV1beta1IngressRule buildLastRule();
    public ExtensionsV1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public A withRules(List<ExtensionsV1beta1IngressRule> rules);
    public A withRules(ExtensionsV1beta1IngressRule... rules);
    public Boolean hasRules();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(ExtensionsV1beta1IngressRule item);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,ExtensionsV1beta1IngressRule item);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,ExtensionsV1beta1IngressTLS item);
    public A setToTls(int index,ExtensionsV1beta1IngressTLS item);
    public A addToTls(ExtensionsV1beta1IngressTLS... items);
    public A addAllToTls(Collection<ExtensionsV1beta1IngressTLS> items);
    public A removeFromTls(ExtensionsV1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<ExtensionsV1beta1IngressTLS> items);
    public A removeMatchingFromTls(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IngressTLS> getTls();
    public List<ExtensionsV1beta1IngressTLS> buildTls();
    public ExtensionsV1beta1IngressTLS buildTl(int index);
    public ExtensionsV1beta1IngressTLS buildFirstTl();
    public ExtensionsV1beta1IngressTLS buildLastTl();
    public ExtensionsV1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    public A withTls(List<ExtensionsV1beta1IngressTLS> tls);
    public A withTls(ExtensionsV1beta1IngressTLS... tls);
    public Boolean hasTls();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(ExtensionsV1beta1IngressTLS item);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,ExtensionsV1beta1IngressTLS item);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressBackendFluent<ExtensionsV1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressRuleFluent<ExtensionsV1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressTLSFluent<ExtensionsV1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/ExtensionsV1beta1IngressSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface ExtensionsV1beta1IngressSpecFluent<A extends ExtensionsV1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public ExtensionsV1beta1IngressBackend getBackend();
    public ExtensionsV1beta1IngressBackend buildBackend();
    public A withBackend(ExtensionsV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(ExtensionsV1beta1IngressBackend item);
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public ExtensionsV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(ExtensionsV1beta1IngressBackend item);
    public String getIngressClassName();
    public A withIngressClassName(String ingressClassName);
    public Boolean hasIngressClassName();
    public A withNewIngressClassName(String arg1);
    public A withNewIngressClassName(StringBuilder arg1);
    public A withNewIngressClassName(StringBuffer arg1);
    public A addToRules(int index,ExtensionsV1beta1IngressRule item);
    public A setToRules(int index,ExtensionsV1beta1IngressRule item);
    public A addToRules(ExtensionsV1beta1IngressRule... items);
    public A addAllToRules(Collection<ExtensionsV1beta1IngressRule> items);
    public A removeFromRules(ExtensionsV1beta1IngressRule... items);
    public A removeAllFromRules(Collection<ExtensionsV1beta1IngressRule> items);
    public A removeMatchingFromRules(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IngressRule> getRules();
    public List<ExtensionsV1beta1IngressRule> buildRules();
    public ExtensionsV1beta1IngressRule buildRule(int index);
    public ExtensionsV1beta1IngressRule buildFirstRule();
    public ExtensionsV1beta1IngressRule buildLastRule();
    public ExtensionsV1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public A withRules(List<ExtensionsV1beta1IngressRule> rules);
    public A withRules(ExtensionsV1beta1IngressRule... rules);
    public Boolean hasRules();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(ExtensionsV1beta1IngressRule item);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,ExtensionsV1beta1IngressRule item);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public ExtensionsV1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,ExtensionsV1beta1IngressTLS item);
    public A setToTls(int index,ExtensionsV1beta1IngressTLS item);
    public A addToTls(ExtensionsV1beta1IngressTLS... items);
    public A addAllToTls(Collection<ExtensionsV1beta1IngressTLS> items);
    public A removeFromTls(ExtensionsV1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<ExtensionsV1beta1IngressTLS> items);
    public A removeMatchingFromTls(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1IngressTLS> getTls();
    public List<ExtensionsV1beta1IngressTLS> buildTls();
    public ExtensionsV1beta1IngressTLS buildTl(int index);
    public ExtensionsV1beta1IngressTLS buildFirstTl();
    public ExtensionsV1beta1IngressTLS buildLastTl();
    public ExtensionsV1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);
    public A withTls(List<ExtensionsV1beta1IngressTLS> tls);
    public A withTls(ExtensionsV1beta1IngressTLS... tls);
    public Boolean hasTls();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(ExtensionsV1beta1IngressTLS item);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,ExtensionsV1beta1IngressTLS item);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public ExtensionsV1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressBackendFluent<ExtensionsV1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressRuleFluent<ExtensionsV1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1IngressTLSFluent<ExtensionsV1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}
